Struct ethers_iqkms::types::Bloom
[−]Expand description
Bloom hash type with 256 bytes (2048 bits) size.
Tuple Fields
0: [u8; 256]Implementations
impl Bloom
impl Bloom
pub const fn repeat_byte(byte: u8) -> Bloom
pub const fn repeat_byte(byte: u8) -> Bloom
Returns a new fixed hash where all bits are set to the given byte.
pub fn as_bytes(&self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn as_bytes(&self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Extracts a byte slice containing the entire fixed hash.
pub fn as_bytes_mut(&mut self) -> &mut [u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn as_bytes_mut(&mut self) -> &mut [u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Extracts a mutable byte slice containing the entire fixed hash.
pub const fn as_fixed_bytes(&self) -> &[u8; 256]
pub const fn as_fixed_bytes(&self) -> &[u8; 256]
Extracts a reference to the byte array containing the entire fixed hash.
pub fn as_fixed_bytes_mut(&mut self) -> &mut [u8; 256]
pub fn as_fixed_bytes_mut(&mut self) -> &mut [u8; 256]
Extracts a reference to the byte array containing the entire fixed hash.
pub const fn to_fixed_bytes(self) -> [u8; 256]
pub const fn to_fixed_bytes(self) -> [u8; 256]
Returns the inner bytes array.
pub fn as_mut_ptr(&mut self) -> *mut u8
pub fn as_mut_ptr(&mut self) -> *mut u8
Returns a mutable raw pointer to the value.
pub fn assign_from_slice(&mut self, src: &[u8])
pub fn assign_from_slice(&mut self, src: &[u8])
pub fn from_slice(src: &[u8]) -> Bloom
pub fn from_slice(src: &[u8]) -> Bloom
impl Bloom
impl Bloom
Utilities using the byteorder crate.
pub fn to_low_u64_be(&self) -> u64
pub fn to_low_u64_be(&self) -> u64
Returns the lowest 8 bytes interpreted as big-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
pub fn to_low_u64_le(&self) -> u64
pub fn to_low_u64_le(&self) -> u64
Returns the lowest 8 bytes interpreted as little-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
pub fn to_low_u64_ne(&self) -> u64
pub fn to_low_u64_ne(&self) -> u64
Returns the lowest 8 bytes interpreted as native-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
pub fn from_low_u64_be(val: u64) -> Bloom
pub fn from_low_u64_be(val: u64) -> Bloom
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as big endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
pub fn from_low_u64_le(val: u64) -> Bloom
pub fn from_low_u64_le(val: u64) -> Bloom
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as little endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
pub fn from_low_u64_ne(val: u64) -> Bloom
pub fn from_low_u64_ne(val: u64) -> Bloom
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as native endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
impl Bloom
impl Bloom
Utilities using the rand crate.
pub fn randomize_using<R>(&mut self, rng: &mut R)where
R: Rng + ?Sized,
pub fn randomize_using<R>(&mut self, rng: &mut R)where
R: Rng + ?Sized,
Assign self to a cryptographically random value using the
given random number generator.
pub fn randomize(&mut self)
pub fn randomize(&mut self)
Assign self to a cryptographically random value.
pub fn random_using<R>(rng: &mut R) -> Bloomwhere
R: Rng + ?Sized,
pub fn random_using<R>(rng: &mut R) -> Bloomwhere
R: Rng + ?Sized,
Create a new hash with cryptographically random content using the given random number generator.
impl Bloom
impl Bloom
pub fn is_empty(&self) -> bool
pub fn contains_input(&self, input: Input<'_>) -> bool
pub fn contains_bloom<'a, B>(&self, bloom: B) -> boolwhere
BloomRef<'a>: From<B>,
pub fn accrue(&mut self, input: Input<'_>)
pub fn accrue_bloom<'a, B>(&mut self, bloom: B)where
BloomRef<'a>: From<B>,
pub fn data(&self) -> &[u8; 256]