pub struct Signature {
    pub r: U256,
    pub s: U256,
    pub v: u64,
}
An ECDSA signature

Fields

r: U256

R value

s: U256

S Value

v: u64

V value

Implementations

Verifies that signature on message was produced by address

Recovers the Ethereum address which was used to sign the given message.

Recovery signature data uses ‘Electrum’ notation, this means the v value is expected to be either 27 or 28.

Retrieve the recovery ID.

Copies and serializes self into a new Vec with the recovery id included