pub struct SyncProgress {
Show 17 fields pub current_block: U64, pub highest_block: U64, pub starting_block: U64, pub pulled_states: Option<U64>, pub known_states: Option<U64>, pub healed_bytecode_bytes: Option<U64>, pub healed_bytecodes: Option<U64>, pub healed_trienode_bytes: Option<U64>, pub healed_trienodes: Option<U64>, pub healing_bytecode: Option<U64>, pub healing_trienodes: Option<U64>, pub synced_account_bytes: Option<U64>, pub synced_accounts: Option<U64>, pub synced_bytecode_bytes: Option<U64>, pub synced_bytecodes: Option<U64>, pub synced_storage: Option<U64>, pub synced_storage_bytes: Option<U64>,
}
Represents the sync status of the node

Note: while the eth_syncing RPC response is defined as:

Returns:

Object|Boolean, An object with sync status data or FALSE, when not syncing:

startingBlock: QUANTITY - The block at which the import started (will only be reset, after the sync reached his head) currentBlock: QUANTITY - The current block, same as eth_blockNumber highestBlock: QUANTITY - The estimated highest block

Geth returns additional fields: https://github.com/ethereum/go-ethereum/blob/0ce494b60cd00d70f1f9f2dd0b9bfbd76204168a/ethclient/ethclient.go#L597-L617

Fields

current_block: U64highest_block: U64starting_block: U64pulled_states: Option<U64>known_states: Option<U64>healed_bytecode_bytes: Option<U64>healed_bytecodes: Option<U64>healed_trienode_bytes: Option<U64>healed_trienodes: Option<U64>healing_bytecode: Option<U64>healing_trienodes: Option<U64>synced_account_bytes: Option<U64>synced_accounts: Option<U64>synced_bytecode_bytes: Option<U64>synced_bytecodes: Option<U64>synced_storage: Option<U64>synced_storage_bytes: Option<U64>