pub struct TransactionReceipt {
Show 15 fields pub transaction_hash: H256, pub transaction_index: U64, pub block_hash: Option<H256>, pub block_number: Option<U64>, pub from: H160, pub to: Option<H160>, pub cumulative_gas_used: U256, pub gas_used: Option<U256>, pub contract_address: Option<H160>, pub logs: Vec<Log, Global>, pub status: Option<U64>, pub root: Option<H256>, pub logs_bloom: Bloom, pub transaction_type: Option<U64>, pub effective_gas_price: Option<U256>,
}
“Receipt” of an executed transaction: details of its execution.

Fields

transaction_hash: H256

Transaction hash.

transaction_index: U64

Index within the block.

block_hash: Option<H256>

Hash of the block this transaction was included within.

block_number: Option<U64>

Number of the block this transaction was included within.

from: H160

address of the sender.

to: Option<H160>cumulative_gas_used: U256

Cumulative gas used within the block after this was executed.

gas_used: Option<U256>

Gas used by this transaction alone.

Gas used is None if the the client is running in light client mode.

contract_address: Option<H160>

Contract address created, or None if not a deployment.

logs: Vec<Log, Global>

Logs generated within this transaction.

status: Option<U64>

Status: either 1 (success) or 0 (failure). Only present after activation of EIP-658

root: Option<H256>

State root. Only present before activation of EIP-658

logs_bloom: Bloom

Logs bloom

transaction_type: Option<U64>

Transaction type, Some(1) for AccessList transaction, None for Legacy

effective_gas_price: Option<U256>

The price paid post-execution by the transaction (i.e. base fee + priority fee). Both fields in 1559-style transactions are maximums (max fee + max priority fee), the amount that’s actually paid by users can only be determined post-execution