Struct ethers_iqkms::types::TxpoolContent
source · [−]pub struct TxpoolContent {
pub pending: BTreeMap<H160, BTreeMap<String, TxpoolTransaction, Global>, Global>,
pub queued: BTreeMap<H160, BTreeMap<String, TxpoolTransaction, Global>, Global>,
}Expand description
Transaction Pool Content
The content inspection property can be queried to list the exact details of all the transactions currently pending for inclusion in the next block(s), as well as the ones that are being scheduled for future execution only.
See here for more details
Fields
pending: BTreeMap<H160, BTreeMap<String, TxpoolTransaction, Global>, Global>pending tx
queued: BTreeMap<H160, BTreeMap<String, TxpoolTransaction, Global>, Global>queued tx