Struct ethers_iqkms::types::TxpoolStatus
source · [−]Expand description
Transaction Pool Status
The status inspection property can be queried for the number of transactions currently pending for inclusion in the next block(s), as well as the ones that are being scheduled for future execution only.
See here for more details
Fields
pending: U64number of pending tx
queued: U64number of queued tx