pub struct TransactionRequest {
    pub from: Option<H160>,
    pub to: Option<NameOrAddress>,
    pub gas: Option<U256>,
    pub gas_price: Option<U256>,
    pub value: Option<U256>,
    pub data: Option<Bytes>,
    pub nonce: Option<U256>,
    pub chain_id: Option<U64>,
}
Parameters for sending a transaction

Fields

from: Option<H160>

Sender address or ENS name

to: Option<NameOrAddress>

Recipient address (None for contract creation)

gas: Option<U256>

Supplied gas (None for sensible default)

gas_price: Option<U256>

Gas price (None for sensible default)

value: Option<U256>

Transferred value (None for no transfer)

data: Option<Bytes>

The compiled code of a contract OR the first 4 bytes of the hash of the invoked method signature and encoded parameters. For details see Ethereum Contract ABI

nonce: Option<U256>

Transaction nonce (None for next available nonce)

chain_id: Option<U64>

Chain ID (None for mainnet)

Implementations

Creates an empty transaction request with all fields left empty

Convenience function for sending a new payment transaction to the receiver.

Sets the from field in the transaction to the provided value

Sets the to field in the transaction to the provided value

Sets the gas field in the transaction to the provided value

Sets the gas_price field in the transaction to the provided value

Sets the value field in the transaction to the provided value

Sets the data field in the transaction to the provided value

Sets the nonce field in the transaction to the provided value

Sets the chain_id field in the transaction to the provided value

Hashes the transaction’s data with the provided chain id

Gets the transaction’s RLP encoding, prepared with the chain_id and extra fields for signing. Assumes the chainid exists.

Gets the unsigned transaction’s RLP encoding

Produces the RLP encoding of the transaction with the provided signature

Decodes RLP into a transaction.

Decodes the given RLP into a transaction, attempting to decode its signature as well.

Sets the access_list field in the transaction (converts the TransactionRequest to an Eip2930TransactionRequest)