Enum ethers_iqkms::types::Chain
source · [−]pub enum Chain {
Show 40 variants
Mainnet,
Morden,
Ropsten,
Rinkeby,
Goerli,
Kovan,
XDai,
Polygon,
Fantom,
Dev,
AnvilHardhat,
FantomTestnet,
PolygonMumbai,
Avalanche,
AvalancheFuji,
Sepolia,
Moonbeam,
Moonbase,
MoonbeamDev,
Moonriver,
Optimism,
OptimismGoerli,
OptimismKovan,
Arbitrum,
ArbitrumTestnet,
ArbitrumGoerli,
Cronos,
CronosTestnet,
BinanceSmartChain,
BinanceSmartChainTestnet,
Poa,
Sokol,
Rsk,
Oasis,
Emerald,
EmeraldTestnet,
Evmos,
EvmosTestnet,
Aurora,
AuroraTestnet,
}Expand description
Enum for all known chains
When adding a new chain:
- add new variant
- update Display/FromStr impl
- add etherscan_keys if supported
Variants
Mainnet
Morden
Ropsten
Rinkeby
Goerli
Kovan
XDai
Polygon
Fantom
Dev
AnvilHardhat
FantomTestnet
PolygonMumbai
Avalanche
AvalancheFuji
Sepolia
Moonbeam
Moonbase
MoonbeamDev
Moonriver
Optimism
OptimismGoerli
OptimismKovan
Arbitrum
ArbitrumTestnet
ArbitrumGoerli
Cronos
CronosTestnet
BinanceSmartChain
BinanceSmartChainTestnet
Poa
Sokol
Rsk
Oasis
Emerald
EmeraldTestnet
Evmos
EvmosTestnet
Aurora
AuroraTestnet
Implementations
sourceimpl Chain
impl Chain
sourcepub fn average_blocktime_hint(&self) -> Option<Duration>
pub fn average_blocktime_hint(&self) -> Option<Duration>
The blocktime varies from chain to chain
It can be beneficial to know the average blocktime to adjust the polling of an Http provider for example.
Note: this will not return the accurate average depending on the time but is rather a sensible default derived from blocktime charts like https://etherscan.com/chart/blocktime https://polygonscan.com/chart/blocktime
sourcepub fn etherscan_urls(&self) -> Option<(&'static str, &'static str)>
pub fn etherscan_urls(&self) -> Option<(&'static str, &'static str)>
Returns the corresponding etherscan URLs
Returns (API URL, BASE_URL), like ("https://api(-chain).etherscan.io/api", "https://etherscan.io")