Struct ethers_iqkms::types::Log
source · [−]pub struct Log {
pub address: H160,
pub topics: Vec<H256, Global>,
pub data: Bytes,
pub block_hash: Option<H256>,
pub block_number: Option<U64>,
pub transaction_hash: Option<H256>,
pub transaction_index: Option<U64>,
pub log_index: Option<U256>,
pub transaction_log_index: Option<U256>,
pub log_type: Option<String>,
pub removed: Option<bool>,
}Expand description
A log produced by a transaction.
Fields
address: H160H160. the contract that emitted the log
topics: Vec<H256, Global>topics: Array of 0 to 4 32 Bytes of indexed log arguments.
(In solidity: The first topic is the hash of the signature of the event
(e.g. Deposit(address,bytes32,uint256)), except you declared the event
with the anonymous specifier.)
data: BytesData
block_hash: Option<H256>Block Hash
block_number: Option<U64>Block Number
transaction_hash: Option<H256>Transaction Hash
transaction_index: Option<U64>Transaction Index
log_index: Option<U256>Integer of the log index position in the block. None if it’s a pending log.
transaction_log_index: Option<U256>Integer of the transactions index position log was created from. None when it’s a pending log.
log_type: Option<String>Log Type
removed: Option<bool>True when the log was removed, due to a chain reorganization. false if it’s a valid log.