Struct ethers_iqkms::types::Signature
source · [−]Expand description
An ECDSA signature
Fields
r: U256R value
s: U256S Value
v: u64V value
Implementations
sourceimpl Signature
impl Signature
sourcepub fn verify<M, A>(&self, message: M, address: A) -> Result<(), SignatureError>where
M: Into<RecoveryMessage>,
A: Into<H160>,
pub fn verify<M, A>(&self, message: M, address: A) -> Result<(), SignatureError>where
M: Into<RecoveryMessage>,
A: Into<H160>,
Verifies that signature on message was produced by address
sourcepub fn recover<M>(&self, message: M) -> Result<H160, SignatureError>where
M: Into<RecoveryMessage>,
pub fn recover<M>(&self, message: M) -> Result<H160, SignatureError>where
M: Into<RecoveryMessage>,
Recovers the Ethereum address which was used to sign the given message.
Recovery signature data uses ‘Electrum’ notation, this means the v
value is expected to be either 27 or 28.
sourcepub fn recovery_id(&self) -> Result<Id, SignatureError>
pub fn recovery_id(&self) -> Result<Id, SignatureError>
Retrieve the recovery ID.