Struct ethers_iqkms::types::SyncProgress
source · [−]pub struct SyncProgress {Show 17 fields
pub current_block: U64,
pub highest_block: U64,
pub starting_block: U64,
pub pulled_states: Option<U64>,
pub known_states: Option<U64>,
pub healed_bytecode_bytes: Option<U64>,
pub healed_bytecodes: Option<U64>,
pub healed_trienode_bytes: Option<U64>,
pub healed_trienodes: Option<U64>,
pub healing_bytecode: Option<U64>,
pub healing_trienodes: Option<U64>,
pub synced_account_bytes: Option<U64>,
pub synced_accounts: Option<U64>,
pub synced_bytecode_bytes: Option<U64>,
pub synced_bytecodes: Option<U64>,
pub synced_storage: Option<U64>,
pub synced_storage_bytes: Option<U64>,
}Expand description
Represents the sync status of the node
Note: while the eth_syncing RPC response is defined as:
Returns:
Object|Boolean, An object with sync status data or FALSE, when not syncing:
startingBlock: QUANTITY - The block at which the import started (will only be reset, after the sync reached his head) currentBlock: QUANTITY - The current block, same as eth_blockNumber highestBlock: QUANTITY - The estimated highest block
Geth returns additional fields: https://github.com/ethereum/go-ethereum/blob/0ce494b60cd00d70f1f9f2dd0b9bfbd76204168a/ethclient/ethclient.go#L597-L617
Fields
current_block: U64highest_block: U64starting_block: U64pulled_states: Option<U64>known_states: Option<U64>healed_bytecode_bytes: Option<U64>healed_bytecodes: Option<U64>healed_trienode_bytes: Option<U64>healed_trienodes: Option<U64>healing_bytecode: Option<U64>healing_trienodes: Option<U64>synced_account_bytes: Option<U64>synced_accounts: Option<U64>synced_bytecode_bytes: Option<U64>synced_bytecodes: Option<U64>synced_storage: Option<U64>synced_storage_bytes: Option<U64>Trait Implementations
sourceimpl Clone for SyncProgress
impl Clone for SyncProgress
sourcefn clone(&self) -> SyncProgress
fn clone(&self) -> SyncProgress
Returns a copy of the value. Read more
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SyncProgress
impl Debug for SyncProgress
sourceimpl<'de> Deserialize<'de> for SyncProgress
impl<'de> Deserialize<'de> for SyncProgress
sourcefn deserialize<__D>(
__deserializer: __D
) -> Result<SyncProgress, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D
) -> Result<SyncProgress, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<SyncProgress> for SyncProgress
impl PartialEq<SyncProgress> for SyncProgress
sourcefn eq(&self, other: &SyncProgress) -> bool
fn eq(&self, other: &SyncProgress) -> bool
sourceimpl Serialize for SyncProgress
impl Serialize for SyncProgress
sourcefn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for SyncProgress
impl StructuralEq for SyncProgress
impl StructuralPartialEq for SyncProgress